@@ -61,6 +61,11 @@
 #  include <libexif/exif-data.h>
 #endif
 
+/* only needed and present on windows */
+#ifndef O_BINARY
+# define O_BINARY 0
+#endif
+
 #define CR(result)       {int __r=(result); if (__r<0) return __r;}
 #define CRU(result,file) {int __r=(result); if (__r<0) {gp_file_unref(file);return __r;}}
 #define CL(result,list)  {int __r=(result); if (__r<0) {gp_list_free(list); return __r;}}
@@ -281,7 +286,7 @@ print_info_action (GPParams *p, const char *folder, const char *filename)
 		if (info.file.fields & GP_FILE_INFO_TYPE)
 			printf (_("  Mime type:   '%s'\n"), info.file.type);
 		if (info.file.fields & GP_FILE_INFO_SIZE)
-			printf (_("  Size:        %lu byte(s)\n"), (unsigned long int)info.file.size);
+			printf (_("  Size:        %llu byte(s)\n"), (unsigned long long int)info.file.size);
 		if (info.file.fields & GP_FILE_INFO_WIDTH)
 			printf (_("  Width:       %i pixel(s)\n"), info.file.width);
 		if (info.file.fields & GP_FILE_INFO_HEIGHT)
@@ -313,7 +318,7 @@ print_info_action (GPParams *p, const char *folder, const char *filename)
 		if (info.preview.fields & GP_FILE_INFO_TYPE)
 			printf (_("  Mime type:   '%s'\n"), info.preview.type);
 		if (info.preview.fields & GP_FILE_INFO_SIZE)
-			printf (_("  Size:        %lu byte(s)\n"), (unsigned long int)info.preview.size);
+			printf (_("  Size:        %llu byte(s)\n"), (unsigned long long int)info.preview.size);
 		if (info.preview.fields & GP_FILE_INFO_WIDTH)
 			printf (_("  Width:       %i pixel(s)\n"), info.preview.width);
 		if (info.preview.fields & GP_FILE_INFO_HEIGHT)
@@ -329,7 +334,7 @@ print_info_action (GPParams *p, const char *folder, const char *filename)
 		if (info.audio.fields & GP_FILE_INFO_TYPE)
 			printf (_("  Mime type:  '%s'\n"), info.audio.type);
 		if (info.audio.fields & GP_FILE_INFO_SIZE)
-			printf (_("  Size:       %lu byte(s)\n"), (unsigned long int)info.audio.size);
+			printf (_("  Size:       %llu byte(s)\n"), (unsigned long long int)info.audio.size);
 		if (info.audio.fields & GP_FILE_INFO_STATUS)
 			printf (_("  Downloaded: %s\n"),
 				(info.audio.status == GP_FILE_STATUS_DOWNLOADED) ? _("yes") : _("no"));
@@ -368,7 +373,7 @@ print_file_action (GPParams *p, const char *folder, const char *filename)
                            (info.file.permissions & GP_FILE_PERM_DELETE) ? "d" : "-");
                 }
                 if (info.file.fields & GP_FILE_INFO_SIZE)
-                    printf(" FILESIZE=%5ld", (unsigned long int)info.file.size);
+                    printf(" FILESIZE=%llu", (unsigned long long int)info.file.size);
                 if ((info.file.fields & GP_FILE_INFO_WIDTH) && +
                     (info.file.fields & GP_FILE_INFO_HEIGHT)) {
                     printf(" IMGWIDTH=%d", info.file.width);
@@ -377,7 +382,7 @@ print_file_action (GPParams *p, const char *folder, const char *filename)
                 if (info.file.fields & GP_FILE_INFO_TYPE)
                     printf(" FILETYPE=%s", info.file.type);
                 if (info.file.fields & GP_FILE_INFO_MTIME)
-                    printf(" FILEMTIME=%ld", info.file.mtime);
+                    printf(" FILEMTIME=%lld", (long long)info.file.mtime);
                 printf("\n");
             } else
                 printf ("FILENAME='%s/%s'\n", folder, filename);
@@ -401,7 +406,7 @@ print_file_action (GPParams *p, const char *folder, const char *filename)
 		    if (info.file.fields & GP_FILE_INFO_TYPE)
                 printf(" %s", info.file.type);
 		    if (info.file.fields & GP_FILE_INFO_MTIME)
-                printf(" %ld", info.file.mtime);
+                printf(" %lld", (long long)info.file.mtime);
 		    putchar ('\n');
 		} else
 		    printf("#%-5i %s\n", x+1, filename);
@@ -928,7 +933,7 @@ print_version_action (GPParams __unused__ *p)
 		  "\n"
 		  "This version of gphoto2 is using the following software versions and options:\n"),
 		VERSION,
-		2021 /* year of release! */
+		2025 /* year of release! */
 		);
 
 	for (n = 0; module_versions[n].name != NULL; n++) {
@@ -1035,7 +1040,7 @@ action_camera_capture_movie (GPParams *p, const char *arg)
 		fd = dup(fileno(stdout));
 		xname = "stdout";
 	} else {
-		fd = open("movie.mjpg",O_WRONLY|O_CREAT,0660);
+		fd = open("movie.mjpg",O_WRONLY|O_CREAT|O_BINARY,0660);
 		if (fd == -1) {
 			cli_error_print(_("Could not open 'movie.mjpg'."));
 			return GP_ERROR;
@@ -1081,6 +1086,12 @@ action_camera_capture_movie (GPParams *p, const char *arg)
 
 		captured_frames++;
 
+		if (end_next) {
+			printf(_("Movie capture: SIGUSR2 signal received, stopping capture!\n"));
+			end_next = 0;
+			break;
+		}
+
 		if (glob_cancel) {
 			fprintf(stderr, _("Ctrl-C pressed ... Exiting.\n"));
 			break;
@@ -1393,11 +1404,11 @@ print_storage_info (GPParams *p)
 			printf("\n");
 		}
 		if (sinfos[i].fields & GP_STORAGEINFO_MAXCAPACITY)
-			printf ("totalcapacity=%lu KB\n", (unsigned long)sinfos[i].capacitykbytes);
+			printf ("totalcapacity=%llu KB\n", (unsigned long long)sinfos[i].capacitykbytes);
 		if (sinfos[i].fields & GP_STORAGEINFO_FREESPACEKBYTES)
-			printf ("free=%lu KB\n", (unsigned long)sinfos[i].freekbytes);
+			printf ("free=%llu KB\n", (unsigned long long)sinfos[i].freekbytes);
 		if (sinfos[i].fields & GP_STORAGEINFO_FREESPACEIMAGES)
-			printf ("freeimages=%lu\n", (unsigned long)sinfos[i].freeimages);
+			printf ("freeimages=%llu\n", (unsigned long long)sinfos[i].freeimages);
 	}
 	if (sinfos)
 		free(sinfos);
