@@ -1,16 +1,16 @@
 /* gphoto2-cmd-config.h
  *
- * Copyright  2001 Lutz Mller <lutz@users.sf.net>
+ * Copyright © 2001 Lutz Müller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -18,14 +18,14 @@
  * Boston, MA  02110-1301  USA
  */
 
-#ifndef __GPHOTO2_CMD_CONFIG_H__
-#define __GPHOTO2_CMD_CONFIG_H__
+#ifndef GPHOTO2_GPHOTO2_CMD_CONFIG_H
+#define GPHOTO2_GPHOTO2_CMD_CONFIG_H
 
 #include <gphoto2/gphoto2-camera.h>
 
 int gp_cmd_config (Camera *camera, GPContext *context);
 
-#endif /* __GPHOTO2_CMD_CONFIG_H__ */
+#endif /* !defined(GPHOTO2_GPHOTO2_CMD_CONFIG_H) */
 
 
 /*
