@@ -1104,7 +1104,7 @@ capture_generic (CameraCaptureType type, const char __unused__ *name, int downlo
 			else if (!capture_now) {
 				/*
 				 * In the case of a (huge) time-sync while gphoto is running,
-				 * gphoto could percieve an extremely large amount of time and
+				 * gphoto could perceive an extremely large amount of time and
 				 * stay "behind schedule" quite forever. That's why I reduce the
 				 * difference of time with the following loop.
 				 * [alesan]
@@ -1215,14 +1215,14 @@ start_timeout_func (Camera *camera, unsigned int timeout,
 
 	pthread_create (&tid, NULL, thread_func, td);
 
-	return (tid);
+	return (unsigned int)tid;
 }
 
 static void
 stop_timeout_func (Camera __unused__ *camera, unsigned int id,
 		   void __unused__ *data)
 {
-	pthread_t tid = id;
+	pthread_t tid = (pthread_t)id;
 
 	pthread_cancel (tid);
 	pthread_join (tid, NULL);
@@ -1307,6 +1307,7 @@ typedef enum {
 	ARG_FOLDER,
 	ARG_FORCE_OVERWRITE,
 	ARG_GET_ALL_AUDIO_DATA,
+	ARG_GET_ALL_EXIF,
 	ARG_GET_ALL_FILES,
 	ARG_GET_ALL_METADATA,
 	ARG_GET_ALL_RAW_DATA,
@@ -1316,6 +1317,7 @@ typedef enum {
 	ARG_SET_CONFIG,
 	ARG_SET_CONFIG_INDEX,
 	ARG_SET_CONFIG_VALUE,
+	ARG_GET_EXIF,
 	ARG_GET_FILE,
 	ARG_GET_METADATA,
 	ARG_GET_RAW_DATA,
@@ -1340,6 +1342,7 @@ typedef enum {
 	ARG_PORT,
 	ARG_QUIET,
 	ARG_RECURSE,
+	ARG_REVERSE,
 	ARG_RESET,
 	ARG_RESET_INTERVAL,
 	ARG_RMDIR,
@@ -1489,6 +1492,10 @@ cb_arg_init (poptContext __unused__ ctx,
 		gp_params.flags |= FLAGS_RECURSE;
 		break;
 
+	case ARG_REVERSE:
+		gp_params.flags |= FLAGS_REVERSE;
+		break;
+
 	case ARG_MODEL:
 		gp_log (GP_LOG_DEBUG, "main", "Processing 'model' "
 			"option ('%s')...", arg);
@@ -1636,6 +1643,9 @@ cb_arg_run (poptContext __unused__ ctx,
 	case ARG_GET_ALL_AUDIO_DATA:
 		params->p.r = for_each_file (&gp_params, save_all_audio_action);
 		break;
+	case ARG_GET_ALL_EXIF:
+		params->p.r = for_each_file (&gp_params, save_exif_action);
+		break;
 	case ARG_GET_ALL_FILES:
 		params->p.r = for_each_file (&gp_params, save_file_action);
 		break;
@@ -1656,6 +1666,10 @@ cb_arg_run (poptContext __unused__ ctx,
 		gp_params.multi_type = MULTI_DOWNLOAD;
 		params->p.r = get_file_common (arg, GP_FILE_TYPE_METADATA);
 		break;
+	case ARG_GET_EXIF:
+		gp_params.multi_type = MULTI_DOWNLOAD;
+		params->p.r = get_file_common (arg, GP_FILE_TYPE_EXIF);
+		break;
 	case ARG_GET_FILE:
 		gp_params.multi_type = MULTI_DOWNLOAD;
 		params->p.r = get_file_common (arg, GP_FILE_TYPE_NORMAL);
@@ -2125,6 +2139,10 @@ main (int argc, char **argv, char **envp)
 		{"get-all-audio-data", '\0', POPT_ARG_NONE, NULL,
 		 ARG_GET_ALL_AUDIO_DATA,
 		 N_("Get all audio data from folder"), NULL},
+		{"get-exif", '\0', POPT_ARG_STRING, NULL, ARG_GET_EXIF,
+		 N_("Get files given in range"), N_("RANGE")},
+		{"get-all-exif", '\0', POPT_ARG_NONE, NULL, ARG_GET_ALL_EXIF,
+		 N_("Get all files from folder"), NULL},
 		{"delete-file", 'd', POPT_ARG_STRING, NULL, ARG_DELETE_FILE,
 		 N_("Delete files given in range"), N_("RANGE")},
 		{"delete-all-files", 'D', POPT_ARG_NONE, NULL,
@@ -2141,6 +2159,8 @@ main (int argc, char **argv, char **envp)
 		 N_("Recursion (default for download)"), NULL},
 		{"no-recurse", '\0', POPT_ARG_NONE, NULL, ARG_NO_RECURSE,
 		 N_("No recursion (default for deletion)"), NULL},
+		{"reverse", '\0', POPT_ARG_NONE, NULL, ARG_REVERSE,
+		 N_("Reverse order of file operations"), NULL},
 		{"new", '\0', POPT_ARG_NONE, NULL, ARG_NEW,
 		 N_("Process new files only"), NULL},
 		{"force-overwrite", '\0', POPT_ARG_NONE, NULL,
@@ -2282,7 +2302,7 @@ main (int argc, char **argv, char **envp)
 	poptResetContext (ctx);
 	while ((cb_params.p.r >= GP_OK) && (poptGetNextOpt (ctx) >= 0));
 	/* Load default values for --filename and --hook-script if not
-	 * explicitely specified
+	 * explicitly specified
 	 */
 	if (!gp_params.filename) {
 		char buf[256];
@@ -2505,7 +2525,7 @@ main (int argc, char **argv, char **envp)
 
 	/*
 	 * Recursion is too dangerous for deletion. Only turn it on if
-	 * explicitely specified.
+	 * explicitly specified.
 	 */
 	cb_params.type = CALLBACK_PARAMS_TYPE_QUERY;
 	cb_params.p.q.found = 0;
