@@ -1,16 +1,16 @@
 /* range.h
  *
- * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright © 2002 Lutz Müller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -18,14 +18,14 @@
  * Boston, MA  02110-1301  USA
  */
 
-#ifndef __RANGE_H__
-#define __RANGE_H__
+#ifndef GPHOTO2_RANGE_H
+#define GPHOTO2_RANGE_H
 
 #include <gphoto2/gphoto2-context.h>
 
 int parse_range (const char *range, char *index, GPContext *context);
 
-#endif /* __RANGE_H__ */
+#endif /* !defined(GPHOTO2_RANGE_H) */
 
 
 /*
